<?xml version="1.0" ?><!DOCTYPE TS><TS language="ku_IQ" version="2.1">
<context>
    <name>CalendarWindow</name>
    <message>
        <location filename="../calendarwindow.cpp" line="203"/>
        <source>First Day of Week</source>
        <translation>Roja Yekem a Hefteyê</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="40"/>
        <source>Deepin Calendar</source>
        <translation>ساڵنامەی Deepin</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="42"/>
        <source>Calendar is a date tool.</source>
        <translation>ساڵنامە ئامرازێکی بەروارە</translation>
    </message>
</context>
<context>
    <name>InfoView</name>
    <message>
        <location filename="../infoview.cpp" line="24"/>
        <source>Today</source>
        <translation>ئەمڕۆ</translation>
    </message>
</context>
</TS>